What's new
==========

Devel
-----

.. py:currentmodule:: piecash.model_core.commodity

- refactor classes
- add helper functions:

  - :func:`Commodity.create_currency_from_ISO`
  - :func:`Commodity.create_stock_from_symbol`


